@@ -15,10 +15,14 @@ if is_py2:
     from urlparse import urljoin, urlparse
 
     str = unicode
+
     import io
+
     open = io.open
 
     import repr as reprlib
+
+    import Queue as queue
 else:
     from urllib.parse import urljoin, urlparse
 
@@ -26,3 +30,5 @@ else:
     open = open
 
     import reprlib
+
+    import queue
